@@ -14,17 +14,24 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ * In addition, as a special exception, Renaud Deraison
+ * gives permission to link the code of this program with any
+ * version of the OpenSSL library which is distributed under a
+ * license identical to that listed in the included COPYING.OpenSSL
+ * file, and distribute linked combinations including the two.
+ * You must obey the GNU General Public License in all respects
+ * for all of the code used other than OpenSSL.  If you modify
+ * this file, you may extend this exception to your version of the
+ * file, but you are not obligated to do so.  If you do not wish to
+ * do so, delete this exception statement from your version.
  */
 
 #ifndef _NESSUSC_AUTH_H
 #define _NESSUSC_AUTH_H
 
 int auth_login(char * , char * );
-char * network_gets(char * , size_t);
+int network_gets(char * , size_t);
 char * network_gets_raw(char * , size_t);
 void network_printf(char * data, ...);
-#ifdef ENABLE_CRYPTO_LAYER
-extern char *stored_pwd ;
-extern const char *get_pwd_callback () ;
-#endif
 #endif
