@@ -47,6 +47,7 @@
 extern int F_quiet_mode;
 
 int comm_send_file(char*);
+static int cli_send_prefs_arglist(struct arglist*, harglst **, int );
 
 /*
  * Parses a plugin description message, and returns an arglist with the
@@ -74,55 +75,64 @@ parse_plugin(buf)
   
   str = parse_separator(buf);if(!str)return NULL;
   arg_add_value(plugin, "NAME", ARG_STRING, strlen(str), estrdup(str));
+  
 
 	
   l   += strlen(str) + 5;
+  free(str);
  
   str =  parse_separator(buf+l);if(!str)return NULL;
   arg_add_value(plugin, "CATEGORY", ARG_STRING, strlen(str),estrdup(str));
 	
   l += strlen(str) + 5;
+  free(str);
   str =  parse_separator(buf+l);if(!str)return NULL;
   arg_add_value(plugin, "COPYRIGHT", ARG_STRING, strlen(str), estrdup(str));
 	
   l+= strlen(str) + 5;
 	
   
+  free(str);
   str = parse_separator(buf+l);if(!str)return  NULL;
   t = str;
   while((t=strchr(t, ';')))t[0]='\n';
   arg_add_value(plugin, "DESCRIPTION", ARG_STRING, strlen(str), estrdup(str));
   l+= strlen(str) + 5;
 	
+  free(str);
   str = parse_separator(buf+l);if(!str)return NULL;
   arg_add_value(plugin, "SUMMARY", ARG_STRING, strlen(str), estrdup(str));
 	
   l+= strlen(str) + 5;
 	
+  free(str);
    str = parse_separator(buf+l);if(!str)return NULL;
    arg_add_value(plugin, "FAMILY", ARG_STRING, strlen(str), estrdup(str));
-   
-   
    l+= strlen(str) + 5;
+   free(str);
    str = parse_separator(buf+l);
    if(str){
    arg_add_value(plugin, "VERSION", ARG_STRING, strlen(str), estrdup(str));
-  
-   
    l+= strlen(str) + 5;
+   free(str);
    str = parse_separator(buf+l);
    if(str != NULL)
     {
     arg_add_value(plugin, "CVE_ID", ARG_STRING, strlen(str), estrdup(str));
     l += strlen(str) + 5;
+    free(str);
    
     str = parse_separator(buf + l);
     if(str != NULL)
      { 
      arg_add_value(plugin, "BUGTRAQ_ID", ARG_STRING, strlen(str), estrdup(str));
      l += strlen(str) + 5;
+     free(str);
      str = parse_separator(buf + l);
-     if( str != NULL )arg_add_value(plugin, "XREFS", ARG_STRING, strlen(str), estrdup(str));
+     if( str != NULL ) {
+	 arg_add_value(plugin, "XREFS", ARG_STRING, strlen(str), estrdup(str));
+	 free(str);
+	 }
      }
    }
    
@@ -413,7 +423,7 @@ cli_comm_get_preferences(prefs)
      if(arg_get_type(plugs_prefs, pref) < 0)
       {
       char * x = strchr(v, ';');
-      if(!ListOnly && x )x[0] = '\0';
+      if(!ListOnly && strstr(v, "[radio]") != NULL && x != NULL )x[0] = '\0';
       arg_add_value(plugs_prefs, pref, ARG_STRING, strlen(v), v);
       }
      }
@@ -981,6 +991,7 @@ audit to be complete");
        }
   PluginsNum = num;
   ScannersNum = num_2;
+  efree(&buf);
   
   return(0);
 }
