@@ -178,13 +178,15 @@ be_mk_index(be)
    char ** lines;
    char ** eols;
    char * sol, * eol;
+   char * eof = NULL;
    
    lines = emalloc(num_allocated_lines*sizeof(*lines));
    eols  = emalloc(num_allocated_lines*sizeof(*eols));
    sol = backends[be].mmap;
+   eof = sol + backends[be].mmap_size;
   
    num_lines = 0;
-   while(sol)
+   while(sol != NULL && sol != eof )
    {
     eol = strchr(sol, '\n');
     lines[num_lines] = sol;
@@ -279,9 +281,9 @@ read_line(be, buf, size)
   int len;
   fstat(backends[be].fd, &buf);
   len = (int)buf.st_size;
+  backends[be].mmap_size = len;
   if((backends[be].mmap = 
-   	mmap(NULL, len, PROT_READ, MAP_SHARED, backends[be].fd, 0)) 
-			== MAP_FAILED)
+   	mmap(NULL, len, PROT_READ, MAP_SHARED, backends[be].fd, 0)) == MAP_FAILED)
    	backends[be].mmap = NULL;
   else
   	 be_mk_index(be);
@@ -1188,7 +1190,14 @@ execute_query_flatfile(be, query)
  struct query * query;
 {
  struct subset * ret = NULL;
- static char buf[1048576];
+ static char *buf = NULL;
+ static int   buf_sz = 0;
+
+ if ( buf == NULL ) {
+	buf_sz = 1024*1024;
+	buf = emalloc(buf_sz);
+ }
+
 #ifdef HAVE_MMAP
  if(backends[be].mmap) backends[be].cur_line = 0;
  else
@@ -1219,7 +1228,6 @@ execute_query_flatfile(be, query)
    { 
    int j;
    char * val = NULL;
-   char buf[1048576];
    char * table;
    char * subnet;
    char * hostname;
@@ -1227,7 +1235,7 @@ execute_query_flatfile(be, query)
    char * plugin_id;
    char * severity;
    char * data;
-   mmap_read_line_n(be, buf, sizeof(buf), i);
+   mmap_read_line_n(be, buf, buf_sz, i);
    __split_line(buf, &table, &subnet, &hostname, &port, &plugin_id, &severity, &data);
    for(j=0;j<query->num;j++)
    {
@@ -1268,7 +1276,7 @@ execute_query_flatfile(be, query)
   return ret;
  }
 #endif 
- while(read_line(be,buf, sizeof(buf)) > 0)
+ while(read_line(be,buf, buf_sz ) > 0)
  {
   char * table;
   char * subnet;
