@@ -1,10 +1,9 @@
 /* Nessus
- * Copyright (C) 1998,1999,2000 Renaud Deraison
+ * Copyright (C) 1998 - 2001 Renaud Deraison
  *
  * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * it under the terms of the GNU General Public License version 2,
+ * as published by the Free Software Foundation
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -15,6 +14,16 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
+ * In addition, as a special exception, Renaud Deraison
+ * gives permission to link the code of this program with any
+ * version of the OpenSSL library which is distributed under a
+ * license identical to that listed in the included COPYING.OpenSSL
+ * file, and distribute linked combinations including the two.
+ * You must obey the GNU General Public License in all respects
+ * for all of the code used other than OpenSSL.  If you modify
+ * this file, you may extend this exception to your version of the
+ * file, but you are not obligated to do so.  If you do not wish to
+ * do so, delete this exception statement from your version.
  */
  
 #include <includes.h>
@@ -23,6 +32,7 @@
 #endif
 
 #include "families.h"
+#include "filter.h"
 #include "globals.h"
 
 /*
@@ -52,11 +62,12 @@ family_add(families,pluginfos)
      struct arglist * pluginfos;
  
 {
-  char * name = (char *)plug_get_family(pluginfos);
+  char * name = arg_get_value(pluginfos, "FAMILY");
   struct plugin_families * l = families;
   int flag = 0;
   if(!name)return;
-  while(l && l->next && !flag)
+  if(l)
+   while(l->next && !flag)
     {
       if(l->name)flag = !strcmp(l->name, name);
       l->enabled = 1;
@@ -79,10 +90,13 @@ family_enable(family, plugins, enable)
      struct arglist * plugins;
      int enable;
 {
-  while(plugins && plugins->next)
+ if(!plugins)
+  return;
+  
+  while(plugins->next)
     {
-      char * pname = (char *)plug_get_family(plugins->value);
-      if(pname && !strcmp(pname, family))
+      char * pname = arg_get_value(plugins->value, "FAMILY");
+      if(!strcmp(pname, family))
       	{ 
 	  switch(enable)
 	  {
@@ -92,14 +106,28 @@ family_enable(family, plugins, enable)
 	   case ENABLE_FAMILY_BUT_DOS :
 	   	{
 		 char* category = arg_get_value(plugins->value, "CATEGORY");	
-		 if(category && !strcmp(category, "denial"))
+		 if(category && (
+				!strcmp(category, "denial") ||
+				!strcmp(category, "kill_host") ||
+				!strcmp(category, "flood") ||
+				!strcmp(category, "destructive_attack")
+				)
+		   )
 		 	plug_set_launch(plugins->value, 0);
 		else
-			plug_set_launch(plugins->value, 1);
+		        {
+			if(!filter_plugin(&Filter, plugins->value))
+			 plug_set_launch(plugins->value, 1);
+			else
+			 plug_set_launch(plugins->value, 0);
+			}
 		break;
 		}
 	   case ENABLE_FAMILY :
-  	  	plug_set_launch(plugins->value, 1);
+	   	if(!filter_plugin(&Filter, plugins->value))
+  	  	  plug_set_launch(plugins->value, 1);
+		else 
+		  plug_set_launch(plugins->value, 0);
 		break;
 	   default : /* nonsense */
 	   	break;
@@ -114,18 +142,41 @@ family_enabled(family, plugins)
  char * family;
  struct arglist * plugins;
 {
- int enabled = 0;
- 
- while(!enabled && plugins && plugins->next)
+ if(!plugins)
+  return 0;
+  
+ while(plugins->next)
     {
-      char * pname =(char *)plug_get_family(plugins->value);
+      char * pname =(char *)arg_get_value(plugins->value, "FAMILY");
       
       if(pname && !strcmp(pname, family))
-  	  enabled = plug_get_launch(plugins->value);
+  	  if(plug_get_launch(plugins->value))
+	   return 1;
       plugins = plugins->next;
     }
- return(enabled);
+ return 0;
 }
+
+int
+family_empty(family, plugins)
+ char * family;
+ struct arglist * plugins;
+{
+ if(!plugins)
+  return 1;
  
+ while(plugins->next)
+ {
+  char * pname =(char *)arg_get_value(plugins->value, "FAMILY");
+  if(pname && !strcmp(pname, family))
+  {
+   if(!filter_plugin(&Filter, plugins->value))
+   return 0;
+  }
+  plugins = plugins->next;
+ }
+ return 1;
+}
+
    
 
