@@ -4,6 +4,10 @@
 
 extern struct arglist * Plugins;
 extern struct arglist * Scanners;
+extern struct arglist * Dependencies;
+#ifdef CLIENTSIDE_PLUGINS
+extern struct arglist * Upload;
+#endif
 extern harglst * NetMap;
 extern int PluginsNum;
 extern int ScannersNum;
@@ -12,6 +16,7 @@ extern struct arglist * MainDialog;
 extern struct arglist * ArgSock;
 extern char * Alt_rcfile;
 extern int GlobalSocket;
+extern struct plugin_filter Filter;
 
 #ifdef ENABLE_SAVE_TESTS
 extern harglst * Sessions;
@@ -26,20 +31,17 @@ extern int F_show_pixmaps;
 extern int F_quiet_mode;
 extern int F_nessusd_running;
 extern int First_time;
+extern int ListOnly;
 
 #ifdef _WIN32
 # include "globals.w32"
-// #define _NO_PIES
+/* #define _NO_PIES */
 #else /* _WIN32 */
-#ifndef ENABLE_CRYPTO_LAYER
 # define closesocket(x) close (x)
-#endif
 #endif /* _WIN32 */
 
-#ifdef ENABLE_CRYPTO_LAYER
-# include "peks/peks.h"
-#else /* ENABLE_CRYPTO_LAYER */
 # define HANDLE int
-#endif /* ENABLE_CRYPTO_LAYER */
+
+#define nulstr(x) (!(x) || ((x)[0] == '\0'))
 
 #endif
