@@ -20,6 +20,9 @@
 #define _NESSUSC_NSR_OUTPUT_H
 
 int arglist_to_file(struct arglist * , char * );
-int file_to_arglist(struct arglist * , char * );
+int file_to_arglist(struct arglist ** , char * );
+
+int backend_to_nsr(int, char*);
+int nsr_to_backend(char*);
 
 #endif
