@@ -306,7 +306,10 @@ prefs_buffer_parse(buffer, arglist)
   while(t[0]==' ' && t[0])t+=sizeof(char);
   if(!t[0])return(1);
   /* remove the spaces after the pref name */
-  while(opt[strlen(opt)-1]==' ')opt[strlen(opt)-1]=0;
+  if ( strchr(buffer, '[') == NULL && strchr(buffer, ']') == NULL )
+    while(opt[strlen(opt)-1]==' ')opt[strlen(opt)-1]=0;
+  else
+    if ( opt[strlen(opt)-1]==' ') opt[strlen(opt)-1]=0;
   
   /* char to int conversion if necessary */
   if(!strcmp(t, "yes"))val = 1;
