@@ -1,6 +1,6 @@
 #ifndef _NESSUSC_PREFS_DIALOG_PLUGINS_PREFS_H
 #define _NESSUSC_PREFS_DIALOG_PLUGINS_PREFS_H
 struct arglist * prefs_dialog_plugins_prefs();
-void prefs_plugins_prefs_redraw(GtkWidget *, void *, struct arglist *);
+int prefs_plugins_prefs_redraw(GtkWidget *, void *, struct arglist *);
 void prefs_plugins_reset(struct arglist *, struct arglist *, struct arglist*);
 #endif
