@@ -162,7 +162,7 @@ read_target_file(bidon, gtkw)
  GtkWidget * bidon;
  GtkWidget * gtkw;
 {
- char * filename = gtk_file_selection_get_filename(GTK_FILE_SELECTION(gtkw));
+ char * filename = (char*)gtk_file_selection_get_filename(GTK_FILE_SELECTION(gtkw));
  char * ret = target_file_name(filename);
  target_file_apply(ret);
  efree(&ret);
