@@ -18,9 +18,10 @@
  
 #ifndef _NESSUSC_REPORT_H
 #define _NESSUSC_REPORT_H
-#define HOLE_PRESENT 2
-#define WARNING_PRESENT 1
-void report_tests(struct arglist *);
+#define HOLE_PRESENT 3
+#define WARNING_PRESENT 2
+#define NOTE_PRESENT 1
+void report_tests(struct arglist *, int);
 int is_there_any_hole(struct arglist *);
 #endif
 
