@@ -22,4 +22,6 @@
 void sighand_pipe();
 void sighand_sigsegv();
 void sighand_alarm();
+void sighand_exit();
+int  nessus_exit(int);
 #endif
