@@ -219,11 +219,14 @@ paranoid.\n";
   else
 #endif
 
-  do {
-  printf("%s", question);
-  ret = 0;
-  }
-  while( (ret = (getc(stdin) - '0')) != 1 && ret != 2 && ret != 3 );
+ do {
+   printf("%s", question);
+   ret = getc(stdin);
+   if ( ret == EOF ) break;
+   else ret -= '0';
+   }
+   while( ret != 1 && ret != 2 && ret != 3 );
+
 
   if(ret >= 1 && ret <= 3)
    {
