@@ -282,10 +282,10 @@ launch_plugin(globals, sched, plugin, hostname, cur_plug, num_plugs, hostinfos,
 	  				attack_user_name(globals),
 	  				hostname);
 	  pluginlaunch_stop();		
-	  if(new_kb)save_kb_close(globals, hostname);	
+	  if(new_kb)save_kb_close(globals, hostname, inet_ntoa(*(struct in_addr *)arg_get_value(hostinfos, "IP")));
 	  if(kb_item_get_int(kb, "Host/ping_failed") > 0)
 	  {
-	   save_kb_restore_backup(globals, hostname);
+	   save_kb_restore_backup(globals, hostname, inet_ntoa(*(struct in_addr *)arg_get_value(hostinfos, "IP")));
 	  }
 	  
 	  plugin_set_running_state(sched, plugin, PLUGIN_STATUS_DONE);				
@@ -342,16 +342,16 @@ attack_host      (globals, hostinfos, hostname,  sched)
   
   if(save_kb(globals))
   {
-   if( save_kb_exists(globals, hostname) != 0 && 
+   if( save_kb_exists(globals, hostname,  inet_ntoa(*(struct in_addr *)arg_get_value(hostinfos, "IP"))) != 0 && 
        save_kb_pref_restore(globals) != 0 )
      {
-      save_kb_backup(globals, hostname);
-      kb = save_kb_load_kb(globals, hostname);
+      save_kb_backup(globals, hostname, inet_ntoa(*(struct in_addr *)arg_get_value(hostinfos, "IP")));
+      kb = save_kb_load_kb(globals, hostname, inet_ntoa(*(struct in_addr *)arg_get_value(hostinfos, "IP")));
       kb_restored = 1; 
      }
    else 
     {
-     save_kb_new(globals, hostname);
+     save_kb_new(globals, hostname, inet_ntoa(*(struct in_addr *)arg_get_value(hostinfos, "IP")));
      kb = kb_new();
      new_kb = 1;
     }
@@ -422,7 +422,7 @@ host_died:
   arg_free(tmp); 
   pluginlaunch_stop();
   plugins_scheduler_free(sched);
-  if(new_kb)save_kb_close(globals, hostname);
+  if(new_kb)save_kb_close(globals, hostname, inet_ntoa(*(struct in_addr *)arg_get_value(hostinfos, "IP")));
 }
 
 /*-----------------------------------------------------------------
@@ -707,7 +707,7 @@ start_attack_network:
     {
     if(save_kb_pref_tested_hosts_only(globals))
     {
-    if(!save_kb_exists(globals, hostname))
+      if(!save_kb_exists(globals, hostname, inet_ntoa(host_ip)))
      {
       log_write("user %s : not testing %s because it has never been tested before\n",
       		 attack_user_name(globals), 
@@ -724,7 +724,7 @@ start_attack_network:
    else if(save_kb_pref_untested_hosts_only(globals))
    {
     /* XXX */
-    if(save_kb_exists(globals, hostname))
+    if(save_kb_exists(globals, hostname, inet_ntoa(host_ip)))
     {
      log_write("user %s : not testing %s because it has already been tested before\n", 
      			attack_user_name(globals), 
