@@ -238,7 +238,7 @@ ntp_11_long_attack(globals, orig)
    else return -1;
   }
  plugin_set = arg_get_value(preferences, "plugin_set");
- if(!plugin_set || plugin_set[0] == '\0' )
+ if( !plugin_set )
  {
   plugin_set = emalloc(3);
   sprintf(plugin_set, "-1");
