@@ -121,9 +121,11 @@ kb_mkdir(dir)
 /*----------------------------------------------------------------
 
  From <hostname>, return 
- /path/to/var/nessus/<username>/kb/<hostname>
+ /path/to/var/nessus/<username>/kb/<hostname>_<ip>
 
+ Hubert Seiwert 2006-01-15: added kb_fname_ip()
 ------------------------------------------------------------------*/
+
 static char*
 kb_fname(globals, hostname)
  struct arglist * globals;
@@ -142,6 +144,30 @@ kb_fname(globals, hostname)
  return ret;
 }
 
+static char*
+kb_fname_ip(globals, hostname, ip)
+ struct arglist * globals;
+ char * hostname;
+ char * ip;
+{
+ char * dir;
+ char * ret;
+ char * hn;
+
+ if ( strcmp(hostname, ip) == 0 )
+	return kb_fname(globals, hostname);
+
+ dir = kb_dirname(globals);
+ hn = strdup(hostname);
+ 
+ hn = filter_odd_name(hn);
+ 
+ ret = emalloc(strlen(dir) + strlen(hn) + strlen(ip) + 3);
+ sprintf(ret, "%s/%s_%s", dir, hn, ip);
+ efree(&dir);
+ efree(&hn);
+ return ret;
+}
 
 /*
  * mmap() tends to sometimes act weirdly
@@ -395,9 +421,10 @@ save_kb_write(globals, hostname, name, value, type)
    
  -------------------------------------------------------------------*/
 int
-save_kb_new(globals, hostname)
+save_kb_new(globals, hostname, ip)
  struct arglist * globals;
  char * hostname;
+ char * ip;
 { 
  char * fname;
  char * dir;
@@ -411,7 +438,7 @@ save_kb_new(globals, hostname)
  kb_mkdir(dir);
  efree(&dir);
  
- fname = kb_fname(globals, hostname);
+ fname = kb_fname_ip(globals, hostname, ip);
  
  if(file_locked(fname))
  {
@@ -441,12 +468,13 @@ save_kb_new(globals, hostname)
 
 
 void
-save_kb_close(globals, hostname)
+save_kb_close(globals, hostname, ip)
  struct arglist * globals;
  char * hostname;
+ char * ip;
 {
  int fd = (int)arg_get_value(globals, "save_kb");
- char* fname = kb_fname(globals, hostname);
+ char* fname = kb_fname_ip(globals, hostname, ip);
  if(fd > 0)close(fd);
  file_unlock(fname);
  efree(&fname);
@@ -459,11 +487,12 @@ save_kb_close(globals, hostname)
  * (returns true if a knowledge base exists)
  */
 int
-save_kb_exists(globals, hostname)
+save_kb_exists(globals, hostname, ip)
  struct arglist * globals;
  char * hostname;
+ char * ip;
 {
- char * fname = kb_fname(globals, hostname);
+ char * fname = kb_fname_ip(globals, hostname, ip);
  FILE *f;
  
  if(file_locked(fname))
@@ -517,11 +546,12 @@ save_kb_write_int(globals, hostname, name, value)
  * Restores a copy of the knowledge base
  */
 int
-save_kb_restore_backup(globals, hostname)
+save_kb_restore_backup(globals, hostname, ip)
  struct arglist * globals;
  char*hostname;
+ char *ip;
 {
- char * fname = kb_fname(globals, hostname);
+ char * fname = kb_fname_ip(globals, hostname, ip);
  char * bakname;
  int fd;
  
@@ -542,11 +572,12 @@ save_kb_restore_backup(globals, hostname)
  */
 
 int
-save_kb_backup(globals, hostname)
+save_kb_backup(globals, hostname, ip)
  struct arglist * globals;
  char* hostname;
+ char* ip;
 {
- char * fname = kb_fname(globals, hostname);
+ char * fname = kb_fname_ip(globals, hostname, ip);
  char * newname = NULL;
  int fd_src = -1, fd_dst = -1;
  
@@ -618,11 +649,12 @@ failed1:
  * entries starting by '/tmp/'
  */
 struct kb_item ** 
-save_kb_load_kb(globals, hostname)
+save_kb_load_kb(globals, hostname, ip)
  struct arglist * globals;
  char * hostname;
+ char * ip;
 {
- char * fname = kb_fname(globals, hostname);
+ char * fname = kb_fname_ip(globals, hostname, ip);
  FILE * f;
  int fd;
  struct kb_item ** kb;
